model

package
v0.13.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 18, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	DefaultName string
	DefaultPath string
	// DefaultLayoutPath is a direct path to a layout file for the default entry
	DefaultLayoutPath string
	SearchDirs        []string
	SearchEntries     []SearchEntry
	Ignore            []string
	RooterPatterns    []string
}

Config holds the application configuration

type Entry

type Entry struct {
	Label string
	Path  string
	// Layout names a layout resolved from configDir/layouts/<name>.yml
	Layout string
	// LayoutPath is a direct path to a layout file (env and ~ expanded)
	LayoutPath string
}

Entry represents a searchable project or directory

type SearchEntry added in v0.10.0

type SearchEntry struct {
	Path   string
	Name   string
	Layout string
}

SearchEntry represents a manual entry with a path and optional custom name

Jump to