Documentation
¶
Index ¶
- func ApplyLayout(server *tmux.Server, initialSession tmux.Session, layout tmuxp.Layout) error
- func BuildEntries(config model.Config) ([]model.Entry, error)
- func EntriesFromDir(dir string, ignore []string, rooterPatterns []string) ([]model.Entry, error)
- func EntryFromSearchEntry(se model.SearchEntry) model.Entry
- func StartSession(name string, path string, layout string, layoutPath string, configDir string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApplyLayout ¶
ApplyLayout applies a tmuxp layout configuration
Supports multiple windows with multiple panes
func BuildEntries ¶
BuildEntries creates a list of all searchable entries based on configuration
func EntriesFromDir ¶
EntriesFromDir finds all project directories within a given directory that match the rooter patterns, ignoring specified directories
func EntryFromSearchEntry ¶ added in v0.10.0
func EntryFromSearchEntry(se model.SearchEntry) model.Entry
EntryFromSearchEntry creates an entry from a SearchEntry. If the entry has a custom name, it is used as the label. Otherwise, the label is derived from the base of the path.
func StartSession ¶
func StartSession(name string, path string, layout string, layoutPath string, configDir string) error
StartSession creates or attaches to a tmux session with the given name and path. If no local .sessionizer.yml exists, it resolves a layout from the direct layoutPath, or from a named layout file at configDir/layouts/<layout>.yml.
Types ¶
This section is empty.